==> linq-to-typescript-2.0.0.tgz: package/test/tests/Last.ts <==
import { InvalidOperationException } from "../../src/index"
import { asAsync, expectAsync, itAsync, itEnumerable, itParallel } from "../TestHelpers"

describe("last", () => {
    itEnumerable("Last", (asEnumerable) => {
        expect(asEnumerable([1, 2]).last()).toBe(2)
    })

    itAsync("LastAsync", async () => {
        expect(await asAsync([1, 2]).last()).toBe(2)
    })

    itParallel("LastParallel", async (asParallel) => {
        expect(await asParallel([1, 2]).last()).toBe(2)
    })

    itEnumerable("LastEmpty", (asEnumerable) => {
        expect(() => asEnumerable([]).last()).toThrowError(InvalidOperationException)
    })

    itAsync("LastEmptyAsync", async () => {
        const expect = await expectAsync(asAsync([]).last())
        expect.toThrowError(InvalidOperationException)
    })

    itParallel("LastEmptyParallel", async (asParallel) => {
        const expect = await expectAsync(asParallel([]).last())
        expect.toThrowError(InvalidOperationException)
    })

    itParallel("LastEmptyParallel", async (asParallel) => {
        const expect = await expectAsync(asParallel([]).last())
        expect.toThrowError(InvalidOperationException)
    })

    itEnumerable("LastPredicate", (asEnumerable) => {
        expect(asEnumerable([1, 2]).last((x) => x === 1)).toBe(1)
    })

    itAsync("LastPredicateAsync", async () => {
        expect(await asAsync([1, 2]).last((x) => x === 1)).toBe(1)
    })

    itParallel("LastPredicateParallel", async (asParallel) => {
        expect(await asParallel([1, 2]).last((x) => x === 1)).toBe(1)
    })
})

==> linq-to-typescript-3.1.0.tgz: package/test/tests/Last.ts <==
import { InvalidOperationException } from "../../src/index"
import { asAsync, expectAsync, itAsync, itEnumerable, itParallel } from "../TestHelpers"

describe("last", () => {
    itEnumerable("Last", (asEnumerable) => {
        expect(asEnumerable([1, 2]).last()).toBe(2)
    })

    itAsync("Last", async () => {
        expect(await asAsync([1, 2]).last()).toBe(2)
    })

    itParallel("Last", async (asParallel) => {
        expect(await asParallel([1, 2]).last()).toBe(2)
    })

    itEnumerable("LastEmpty", (asEnumerable) => {
        expect(() => asEnumerable([]).last()).toThrowError(InvalidOperationException)
    })

    itAsync("LastEmpty", async () => {
        const expect = await expectAsync(asAsync([]).last())
        expect.toThrowError(InvalidOperationException)
    })

    itParallel("LastEmpty", async (asParallel) => {
        const expect = await expectAsync(asParallel([]).last())
        expect.toThrowError(InvalidOperationException)
    })

    itEnumerable("LastPredicate", (asEnumerable) => {
        expect(asEnumerable([1, 2]).last((x) => x === 1)).toBe(1)
    })

    itAsync("LastPredicate", async () => {
        expect(await asAsync([1, 2]).last((x) => x === 1)).toBe(1)
    })

    itParallel("LastPredicate", async (asParallel) => {
        expect(await asParallel([1, 2]).last((x) => x === 1)).toBe(1)
    })

    itEnumerable("Last Empty With Predicate", (asEnumerable) => {
        expect(() => asEnumerable([]).last((x) => x > 2))
            .toThrowError(InvalidOperationException)
    })

    itAsync("Last Empty With Predicate", async () => {
        const expect = await expectAsync(asAsync([]).last((x) => x > 2))
        expect.toThrowError(InvalidOperationException)
    })

    itParallel("Last Empty With Predicate", async (asParallel) => {
        const expect = await expectAsync(asParallel([]).last((x) => x > 2))
        expect.toThrowError(InvalidOperationException)
    })
})
